<?php

////////////////////////////////////////////////////////////////////////////////
//  Code fragment to define the module version etc.
//  This fragment is called by /admin/index.php
////////////////////////////////////////////////////////////////////////////////

$module->version  = 2010080300;
$module->requires = 2010080300;  // Requires this Moodle version
$module->cron     = 0;


